@@ -332,6 +332,11 @@ class Optimization:
                 param_state_dict[k] = self.hyper[k](i)
         self._optimizer.load_state_dict(state_dict)
         return self._optimizer
+    
+    def new_iter(self):
+        optimizer = self.optimizer(self._index)
+        self._index += 1
+        return optimizer
             
     def minimize(self, loss, **kwargs):
         if callable(loss): self.loss.append((1, loss)); return
@@ -344,9 +349,9 @@ class Optimization:
     def maximize(self, loss, **kwargs):
         if callable(loss): self.loss.append((-1, loss)); return
         optimizer = self.optimizer(self._index)
-        self.optimizer.zero_grad()
+        optimizer.zero_grad()
         (-loss).backward(**kwargs)
-        self.optimizer.step()
+        optimizer.step()
         self._index += 1
 
     @alias("optimize")
